@@ -1,10 +1,14 @@
-from sym.cli.helpers.os import find_command
+from sym.shared.cli.helpers.os import has_command
+
+from sym.cli.errors import SAMLClientNotFound
+from sym.cli.helpers.config import Config
 from sym.cli.saml_clients.saml_client_factory import SAMLClientFactory
 
-from ...errors import SAMLClientNotFound
-from ..config import Config
 from .model import CheckContext, CheckResult, SymCheck, failure, success
 
+# TODO: these error messages are quite terrible, and should
+# be replaced with the existing ones in errors.py and decorators.py.
+
 
 class LoginCheck(SymCheck):
     def check(self, _: CheckContext) -> CheckResult:
@@ -19,7 +23,7 @@ class DependenciesCheck(SymCheck):
         self.binary = binary
 
     def check(self, _: CheckContext) -> CheckResult:
-        if find_command(self.binary):
+        if has_command(self.binary):
             return success(f"Found on path: {self.binary}")
         else:
             return failure(f"Could not find binary on path: {self.binary}")
