@@ -1,6 +1,7 @@
 from typing import List
 
-from sym.cli.data.global_options_base import GlobalOptionsBase
+from sym.shared.cli.data.global_options_base import GlobalOptionsBase
+
 from sym.cli.helpers.check.model import CheckContext, CheckError, SymCheck
 from sym.cli.helpers.check.ssh import (
     EnsureSshKeyAuthorizedCheck,
