@@ -1,7 +1,8 @@
 from typing import Optional
 
-from ...saml_clients.saml_client import SAMLClient
-from ..config.config import Config
+from sym.cli.helpers.config import Config
+from sym.cli.saml_clients.saml_client import SAMLClient
+
 from .client import RunningInstance
 from .multiregion import MultiRegionEc2Client
 
@@ -17,18 +18,13 @@ class CachingEc2Client(MultiRegionEc2Client):
         an entry in "aliases" that matches.
         """
         for instance_id, server in Config.get_servers().items():
-            try:
-                region = server["region"]
-                if region:
-                    if alias == instance_id:
-                        return RunningInstance(instance_id=alias, region=region)
-
-                    for known_alias in server["aliases"]:
-                        if alias == known_alias:
-                            return RunningInstance(instance_id=instance_id, region=region)
-            except KeyError:
-                self.client.dprint("found invalid cache entry - region missing")
+            if (region := server.get("region")) :
+                if alias == instance_id:
+                    return RunningInstance(instance_id=alias, region=region)
 
+                for known_alias in server.get("aliases", []):
+                    if alias == known_alias:
+                        return RunningInstance(instance_id=instance_id, region=region)
         return None
 
     def _store_to_config(self, alias: str, instance: RunningInstance):
